Index

C G M O S T 
All Classes and Interfaces|All Packages

C

customize(TrackerConfiguration.TrackerConfigurationBuilder) - Method in interface org.matomo.java.tracking.spring.TrackerConfigurationBuilderCustomizer
Customize the TrackerConfiguration.TrackerConfigurationBuilder.

G

getApiEndpoint() - Method in class org.matomo.java.tracking.spring.MatomoTrackerProperties
The Matomo Tracking HTTP API endpoint.
getConnectTimeout() - Method in class org.matomo.java.tracking.spring.MatomoTrackerProperties
The timeout until a connection is established.
getDefaultAuthToken() - Method in class org.matomo.java.tracking.spring.MatomoTrackerProperties
The authorization token (parameter token_auth) to use if not specified explicitly.
getDefaultSiteId() - Method in class org.matomo.java.tracking.spring.MatomoTrackerProperties
The default ID of the website that will be used if not specified explicitly.
getDisableSslCertValidation() - Method in class org.matomo.java.tracking.spring.MatomoTrackerProperties
Disables SSL certificate validation.
getDisableSslHostVerification() - Method in class org.matomo.java.tracking.spring.MatomoTrackerProperties
Disables SSL host verification.
getEnabled() - Method in class org.matomo.java.tracking.spring.MatomoTrackerProperties
Allows to stop the tracker to send requests to the Matomo endpoint.
getLogFailedTracking() - Method in class org.matomo.java.tracking.spring.MatomoTrackerProperties
Logs if the Matomo Tracking API endpoint responds with an erroneous HTTP code.
getProxyHost() - Method in class org.matomo.java.tracking.spring.MatomoTrackerProperties
The hostname or IP address of an optional HTTP proxy.
getProxyPassword() - Method in class org.matomo.java.tracking.spring.MatomoTrackerProperties
The corresponding password for the basic auth proxy user.
getProxyPort() - Method in class org.matomo.java.tracking.spring.MatomoTrackerProperties
The port of an HTTP proxy.
getProxyUsername() - Method in class org.matomo.java.tracking.spring.MatomoTrackerProperties
If the HTTP proxy requires a username for basic authentication, it can be configured here.
getSocketTimeout() - Method in class org.matomo.java.tracking.spring.MatomoTrackerProperties
The socket timeout (SO_TIMEOUT), which is the timeout for waiting for data or, put differently, a maximum period inactivity between two consecutive data packets.
getThreadPoolSize() - Method in class org.matomo.java.tracking.spring.MatomoTrackerProperties
The thread pool size for the async sender.
getUserAgent() - Method in class org.matomo.java.tracking.spring.MatomoTrackerProperties
A custom user agent to be set.

M

matomoTracker(TrackerConfiguration) - Method in class org.matomo.java.tracking.spring.MatomoTrackerAutoConfiguration
A MatomoTracker instance based on the current configuration.
MatomoTrackerAutoConfiguration - Class in org.matomo.java.tracking.spring
Auto configuration for Matomo Tracker.
MatomoTrackerAutoConfiguration() - Constructor for class org.matomo.java.tracking.spring.MatomoTrackerAutoConfiguration
 
MatomoTrackerProperties - Class in org.matomo.java.tracking.spring
Configuration properties for the Matomo Tracker.
MatomoTrackerProperties() - Constructor for class org.matomo.java.tracking.spring.MatomoTrackerProperties
 
matomoTrackerSpringFilter(MatomoTracker) - Method in class org.matomo.java.tracking.spring.MatomoTrackerAutoConfiguration
A FilterRegistrationBean for the MatomoTrackerFilter.

O

org.matomo.java.tracking.spring - package org.matomo.java.tracking.spring
Provides Spring specific classes to integrate Matomo tracking into Spring applications.

S

setApiEndpoint(String) - Method in class org.matomo.java.tracking.spring.MatomoTrackerProperties
The Matomo Tracking HTTP API endpoint.
setConnectTimeout(Duration) - Method in class org.matomo.java.tracking.spring.MatomoTrackerProperties
The timeout until a connection is established.
setDefaultAuthToken(String) - Method in class org.matomo.java.tracking.spring.MatomoTrackerProperties
The authorization token (parameter token_auth) to use if not specified explicitly.
setDefaultSiteId(Integer) - Method in class org.matomo.java.tracking.spring.MatomoTrackerProperties
The default ID of the website that will be used if not specified explicitly.
setDisableSslCertValidation(Boolean) - Method in class org.matomo.java.tracking.spring.MatomoTrackerProperties
Disables SSL certificate validation.
setDisableSslHostVerification(Boolean) - Method in class org.matomo.java.tracking.spring.MatomoTrackerProperties
Disables SSL host verification.
setEnabled(Boolean) - Method in class org.matomo.java.tracking.spring.MatomoTrackerProperties
Allows to stop the tracker to send requests to the Matomo endpoint.
setLogFailedTracking(Boolean) - Method in class org.matomo.java.tracking.spring.MatomoTrackerProperties
Logs if the Matomo Tracking API endpoint responds with an erroneous HTTP code.
setProxyHost(String) - Method in class org.matomo.java.tracking.spring.MatomoTrackerProperties
The hostname or IP address of an optional HTTP proxy.
setProxyPassword(String) - Method in class org.matomo.java.tracking.spring.MatomoTrackerProperties
The corresponding password for the basic auth proxy user.
setProxyPort(Integer) - Method in class org.matomo.java.tracking.spring.MatomoTrackerProperties
The port of an HTTP proxy.
setProxyUsername(String) - Method in class org.matomo.java.tracking.spring.MatomoTrackerProperties
If the HTTP proxy requires a username for basic authentication, it can be configured here.
setSocketTimeout(Duration) - Method in class org.matomo.java.tracking.spring.MatomoTrackerProperties
The socket timeout (SO_TIMEOUT), which is the timeout for waiting for data or, put differently, a maximum period inactivity between two consecutive data packets.
setThreadPoolSize(Integer) - Method in class org.matomo.java.tracking.spring.MatomoTrackerProperties
The thread pool size for the async sender.
setUserAgent(String) - Method in class org.matomo.java.tracking.spring.MatomoTrackerProperties
A custom user agent to be set.
standardTrackerConfigurationBuilderCustomizer(MatomoTrackerProperties) - Method in class org.matomo.java.tracking.spring.MatomoTrackerAutoConfiguration
Configures the TrackerConfiguration.TrackerConfigurationBuilder with the properties from MatomoTrackerProperties.

T

trackerConfiguration(TrackerConfiguration.TrackerConfigurationBuilder) - Method in class org.matomo.java.tracking.spring.MatomoTrackerAutoConfiguration
Creates a TrackerConfiguration instance based on the current configuration.
trackerConfigurationBuilder(List<TrackerConfigurationBuilderCustomizer>) - Method in class org.matomo.java.tracking.spring.MatomoTrackerAutoConfiguration
Creates a TrackerConfiguration.TrackerConfigurationBuilder and applies all TrackerConfigurationBuilderCustomizers.
TrackerConfigurationBuilderCustomizer - Interface in org.matomo.java.tracking.spring
Allows to customize the TrackerConfiguration.TrackerConfigurationBuilder with additional properties.
C G M O S T 
All Classes and Interfaces|All Packages